// flagReset.cpp : Defines the entry point for the DLL application.
//

#include <string>
#include <vector>
#include "bzfsAPI.h"

BZ_GET_PLUGIN_VERSION

class flagReset : public bz_EventHandler
{
public:
	virtual void process (bz_EventData *eventData);
	std::vector<std::string>* explode (std::string src, char s);
	int strToInt (std::string src);

	double lastreset;
	bool haswarned;

	int freq;
	int warning;
	bool all;
};

flagReset fr;

BZF_PLUGIN_CALL int bz_Load ( const char* commandLine )
{
	std::string rawparams = commandLine;
	std::vector<std::string>* params = fr.explode(rawparams, ':');

	//initialize stuff (defaults)
	fr.freq = 3600;
	fr.warning = 0;
	fr.all = false;

	fr.lastreset = 0.0;
	fr.haswarned = false;


	if (params->size() >= 1 && fr.strToInt(params->at(0)) != 0)
	{
		fr.freq = 60 * fr.strToInt(params->at(0));
	}
	if (params->size() >= 2)
	{
		fr.warning = fr.strToInt(params->at(1));
	}
	if (params->size() >= 3 && params->at(2) == "all")
	{
		fr.all = true;
	}

	params->clear();
	delete params;

	bz_registerEvent (bz_eTickEvent, &fr);
  bz_debugMessage(4,"flagReset plugin loaded");
  return 0;
}

BZF_PLUGIN_CALL int bz_Unload ( void )
{
	bz_removeEvent (bz_eTickEvent, &fr);
  bz_debugMessage(4,"flagReset plugin unloaded");
  return 0;
}

std::vector<std::string>* flagReset::explode(std::string src, char s)
{
	std::vector<std::string>* list = new std::vector<std::string>;

	int index = 0;
	list->push_back("");

	for (unsigned int x = 0; x < src.length(); x++)
	{
		if (src[x] == s)
		{
			index++;
			list->push_back("");
		}
		else
		{
			list->at(index) += src[x];
		}
	}
	return list;
}

int flagReset::strToInt (std::string src)
{
	int val = 0;
	int digit;
	for (unsigned int x = 0; x < src.length(); x++)
	{
		if (src[x] < '0' || src[x] > '9')
		{
			return 0; //not an integer
		}
		digit = static_cast<int> (src[x] - '0');
		val *= 10;
		val += digit;
	}
	return val;
}

void flagReset::process (bz_EventData *eventData)
{
	double thetime = bz_getCurrentTime();
	if (thetime - fr.lastreset > fr.freq)
	{
		bz_resetFlags(!fr.all);
		fr.lastreset = thetime;
		fr.haswarned = false;
	}
	else if (fr.warning != 0 && !haswarned && thetime - fr.lastreset > fr.freq - fr.warning)
	{
		bz_sendTextMessagef(BZ_SERVER, BZ_ALLUSERS, "Automatic flag reset in %d seconds.", fr.warning);
		fr.haswarned = true;
	}
}

// Local Variables: ***
// mode:C++ ***
// tab-width: 8 ***
// c-basic-offset: 2 ***
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8

